# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext_lazy as _
from django.utils.translation import ugettext as ugt
from django.conf import settings
from django.db import transaction

from jumbo.core.urlresolvers import reverse
from jumbo.admin.options import ExtendibleModelAdmin, OrderedModelAdmin, SettingsAdmin
from jumbo.forms.models import AdminModelForm
from jumbo.utils.functions import get_settings

from openvpn.models import Key, Certificate, Connection, FwRule, FwGroup
from openvpn import views as openvpn_views
from openvpn.certificate_form import CertificateForm

class KeyAdmin(ExtendibleModelAdmin):
    model = Key
    list_display = (
        'get_status_icon', 'user', 'identity', 'get_edit_icon',
        'get_detail_icon', 'get_delete_icon'
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create', 'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (None, {"fields": (
            'status', 'user', 'identity', 'path_pub', 'path_priv',
        ),}),
    )

#class CertificateForm(AdminModelForm):
#    class Meta:
#        model = Certificate

class CertificateAdmin(ExtendibleModelAdmin):
    model = Certificate
    form = CertificateForm
    list_display = (
        'get_status_icon', 'get_user', 'description', 'start_date', 'stop_date', 'cn',
        'get_edit_icon', 'get_detail_icon', 'get_download_icon', 'get_delete_icon'
    )
    default_group_by = 'group'
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                ('creator', 'date_create'), ('last_modifier', 'date_last_modify'),
            ),
            'classes': ('collapse',)
        }),
        (None, {"fields": (
            'status', ('user', 'group',), ('start_date', 'stop_date',),
            'description',
        ),}),
    )

    def get_user(self, result):
        return "%s %s" % (result.user.last_name, result.user.first_name)

    get_user.short_description = _("user")

    def get_urls(self):
        from django.conf.urls.defaults import patterns, url
        urls = super(CertificateAdmin, self).get_urls()
        my_urls = patterns('',
            url(
                r'^certificate/download/(?P<object_id>\d+)/$',
                self.admin_site.admin_view(openvpn_views.download_certificate),
                name = 'openvpn-certificate-download'
            )
        )
        return my_urls + urls

    def get_download_icon(self, result):
        return """
            <a href=%(reverse_url)s>
                <img src='%(url)sadmin/images/download.png' alt='%(window_title)s' />
            </a>
        """ % {
            'reverse_url':reverse('admin:openvpn-certificate-download', result.id),
            'url':settings.MEDIA_URL,
            'window_title':ugt("Download Certificate")
        }
    get_download_icon.short_description = _("D")
    get_download_icon.allow_tags = True

class ConnectionAdmin(ExtendibleModelAdmin):
    model = Connection
    list_display = (
        'get_status_icon', 'certificate', 'start_date', 'stop_date',
        'ip_client', 'get_edit_icon', 'get_detail_icon', 'get_delete_icon'
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': ('date_create', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (None, {"fields": (
            'certificate', 'stop_date', 'ip_client'
        ),}),
    )

    def get_urls(self):
        from django.conf.urls.defaults import patterns, url
        urls = super(ConnectionAdmin, self).get_urls()
        my_urls = patterns('',
            url(
                r'^get_status_openvpn/$',
                self.admin_site.admin_view(openvpn_views.get_status_openvpn),
                name='openvpn_openvpn_get_status'
            ),
            url(
                r'^on_off_openvpn/$',
                self.admin_site.admin_view(openvpn_views.onoff_openvpn),
                name='openvpn_openvpn_onoff'
            ),
            url(
                r'^restart_openvpn/$',
                self.admin_site.admin_view(openvpn_views.restart_openvpn),
                name='openvpn_openvpn_restart'
            ),
        )
        return my_urls + urls

class FwRuleAdmin(ExtendibleModelAdmin):
    model = FwRule
    list_display = (
        'get_status_icon', 'get_groups', 'ip_src', 'ip_dest',
        'proto', 'port_dest', 'action', 'order',
        'get_edit_icon', 'get_detail_icon', 'get_delete_icon'
    )
    default_group_by = 'chain'
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create', 'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (None, {"fields": (
            'status', 'groups',
            ('table', 'chain',),
            ('ip_src', 'ip_dest',),
            ('proto', 'port_dest',),
            ('action',  'order'),
        ),}),
    )

class FwGroupAdmin(ExtendibleModelAdmin):
    model = FwGroup
    list_display = (
        'get_status_icon', 'name',
        'get_edit_icon', 'get_detail_icon', 'get_delete_icon'
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create', 'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (None, {"fields": (
            'status', 'name',
        ),}),
    )

admin.site.register(Key, KeyAdmin)
admin.site.register(Certificate, CertificateAdmin)
admin.site.register(Connection, ConnectionAdmin)
admin.site.register(FwRule, FwRuleAdmin)
admin.site.register(FwGroup, FwGroupAdmin)